/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_KALIGN_CONTEXT_H_
#define _U2_KALIGN_CONTEXT_H_

namespace U2 {

struct KalignException {
	KalignException();
	KalignException(const char* str);
	char str[4096];
};

} //namespace U2

#endif //_U2_KALIGN_CONTEXT_H_

